# Welcome to bento-sts

This is a flask-based implementation of the Simple Terminology Service (STS) for the Bento Metadatabase (MDB).

## Install

	$ git clone https://github.com/CBIIT/bento-sts.git
	$ cd pysts
	$ virtualenv sts-venv
	$ source sts-venv/bin/activate
	$ pip install -r requirements.txt
	$ flask run

## Dependencies

`bento-sts` requires a Neo4j-based [MDB](https://github.com/CBIIT/bento-meta).



